<?php
/*
Plugin Name: NC WebP Image Converter
Plugin URI: nyarcode.com
Description: Convierte imágenes subidas a la biblioteca de medios a formato WebP automáticamente.
Version: 1.0.0
Author: David Cameselle Martín
license: MIT License
*/

if (!defined('ABSPATH')) {
    exit;
}

class NC_WebP_Image_Converter {

    public function __construct() {
        add_filter('wp_handle_upload', array($this, 'convert_to_webp'));
        add_filter('mime_types', array($this, 'add_webp_mime_type'));
        add_filter('wp_check_filetype_and_ext', array($this, 'check_webp_filetype'), 10, 4);
    }

    public function convert_to_webp($upload) {
        $file_path = $upload['file'];
        $file_type = $upload['type'];
    
        if (strpos($file_type, 'image') !== false) {
            $image = $this->create_image_from_file($file_path, $file_type);
            if ($image) {
                $webp_path = preg_replace('/\.[^.]+$/', '.webp', $file_path);
                if (imagewebp($image, $webp_path)) {
                    imagedestroy($image);
    
                    // Update the upload array to point to the new WebP file
                    $upload['file'] = $webp_path;
                    $upload['url'] = preg_replace('/\.[^.]+$/', '.webp', $upload['url']);
                    $upload['type'] = 'image/webp';
                } else {
                    error_log('Failed to create WebP image: ' . $webp_path);
                }
            } else {
                error_log('Failed to create image from file: ' . $file_path);
            }
        }
    
        return $upload;
    }

    public function add_webp_mime_type($mimes) {
        $mimes['webp'] = 'image/webp';
        return $mimes;
    }

    public function check_webp_filetype($data, $file, $filename, $mimes) {
        $wp_filetype = wp_check_filetype($filename, $mimes);
        if ($wp_filetype['ext'] === 'webp') {
            $data['ext'] = 'webp';
            $data['type'] = 'image/webp';
        }
        return $data;
    }

    private function create_image_from_file($file_path, $file_type) {
        switch ($file_type) {
            case 'image/jpeg':
                return imagecreatefromjpeg($file_path);
            case 'image/png':
                return imagecreatefrompng($file_path);
            case 'image/gif':
                return imagecreatefromgif($file_path);
            default:
                return false;
        }
    }
}

new NC_WebP_Image_Converter();
?>